@@ -4,13 +4,14 @@ set -x
 
 start_dir=$(pwd)
 
-KMC_VERSION=2.3.0
+KMC_VERSION=3.0.0
 MUMMER_VERSION=3.23
 SAMTOOLS_VERSION=${SAMTOOLS_VERSION:-"1.3"}
 SMALT_VERSION=0.7.6
 
-KMC_DOWNLOAD_URL=http://sun.aei.polsl.pl/REFRESH/kmc/downloads/${KMC_VERSION}/linux/kmc
-KMCDUMP_DOWNLOAD_URL=http://sun.aei.polsl.pl/REFRESH/kmc/downloads/${KMC_VERSION}/linux/kmc_dump
+#KMC_DOWNLOAD_URL=http://sun.aei.polsl.pl/REFRESH/kmc/downloads/${KMC_VERSION}/linux/kmc
+#KMCDUMP_DOWNLOAD_URL=http://sun.aei.polsl.pl/REFRESH/kmc/downloads/${KMC_VERSION}/linux/kmc_dump
+KMC3_DOWNLOAD_URL="https://github.com/refresh-bio/KMC/releases/download/v${KMC_VERSION}/KMC3.linux.tar.gz"
 MUMMER_DOWNLOAD_URL="http://downloads.sourceforge.net/project/mummer/mummer/${MUMMER_VERSION}/MUMmer${MUMMER_VERSION}.tar.gz"
 SAMTOOLS_DOWNLOAD_URL="https://github.com/samtools/samtools/releases/download/${SAMTOOLS_VERSION}/samtools-${SAMTOOLS_VERSION}.tar.bz2"
 SMALT_DOWNLOAD_URL=http://downloads.sourceforge.net/project/smalt/smalt-${SMALT_VERSION}-bin.tar.gz
@@ -43,9 +44,15 @@ kmc_dir="$build_dir/kmc-${KMC_VERSION}"
 rm -fr $kmc_dir
 mkdir $kmc_dir
 cd $kmc_dir
-download $KMC_DOWNLOAD_URL "kmc"
-download $KMCDUMP_DOWNLOAD_URL "kmc_dump"
-chmod +x kmc kmc_dump
+#download $KMC3_DOWNLOAD_URL "kmc"
+#download $KMCDUMP_DOWNLOAD_URL "kmc_dump"
+#chmod +x kmc kmc_dump
+
+download "${KMC3_DOWNLOAD_URL}" "KMC3.linux.tar.gz"
+tar xzf KMC3.linux.tar.gz
+chmod +x kmc
+chmod +x kmc_tools
+chmod +x kmc_dump
 
 
 # --------------- mummer ------------------
@@ -89,4 +96,4 @@ update_path ${mummer_dir}
 update_path ${samtools_dir}
 update_path ${smalt_dir}
 
-
+pip install cython
